| getColumnIndex | R Documentation |
Column indexes in data of the variable fitting the provided protoname.
getColumnIndex(data, protoname)
data |
Tibble or data.frame. Table returned by |
protoname |
String. Protoname of a variable. |
Returns the column indexes in data of the variable fitting the provided protoname.
Examples in help page of seqFromWaves.
Vector of indexes of the columns of data corresponding to the protoname.
seqFromWaves
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.